@@ -7,7 +7,7 @@
 *
 *	This file part of:	SWarp
 *
-*	Copyright:		(C) 2000-2010 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 2000-2019 IAP/CNRS/SorbonneU
 *
 *	License:		GNU General Public License
 *
@@ -22,7 +22,7 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SWarp. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		26/10/2010
+*	Last modified:		03/12/2019
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -63,6 +63,9 @@ void	make_back(fieldstruct *field, fieldstruct *wfield, int wscale_flag)
    size_t	bufsize, bufsize2,
 		bufshift, size,meshsize,jumpsize;
    off_t	fcurpos,wfcurpos, wfcurpos2,fcurpos2;
+#ifdef HAVE_CFITSIO
+   off_t	cfitsio_fcurpos,cfitsio_wfcurpos, cfitsio_wfcurpos2,cfitsio_fcurpos2;
+#endif // HAVE_CFITSIO
    int		i,j,k,m,n, step, nlines,
 		w,bw, bh, nx,ny,nb,
 		lflag, nr;
@@ -95,10 +98,20 @@ void	make_back(fieldstruct *field, fieldstruct *wfield, int wscale_flag)
   wfcurpos = wfcurpos2 = 0;	/* to avoid gcc -Wall warnings */
   QFSEEK(tab->cat->file, tab->bodypos, SEEK_SET, field->filename);
   QFTELL(fcurpos, tab->cat->file, field->filename);
+#ifdef HAVE_CFITSIO
+  cfitsio_wfcurpos = cfitsio_wfcurpos2 = 0;	/* to avoid gcc -Wall warnings */
+  tab->currentElement = 1; // CFITSIO
+  cfitsio_fcurpos = (fcurpos - tab->bodypos)/tab->bytepix;
+#endif // HAVE_CFITSIO
+
   if (wfield)
     {
     QFSEEK(wtab->cat->file, wtab->bodypos, SEEK_SET, wfield->filename);
     QFTELL(wfcurpos, wtab->cat->file, wfield->filename);
+#ifdef HAVE_CFITSIO
+    wtab->currentElement = 1;
+    cfitsio_wfcurpos = (wfcurpos - wtab->bodypos)/wtab->bytepix;
+#endif // HAVE_CFITSIO
     }
 
 /* Allocate a correct amount of memory to store pixels */
@@ -186,8 +199,17 @@ void	make_back(fieldstruct *field, fieldstruct *wfield, int wscale_flag)
       {
 /*---- Image size too big, we have to skip a few data !*/
       QFTELL(fcurpos2, tab->cat->file, field->filename);
+#ifdef HAVE_CFITSIO
+      cfitsio_fcurpos2 = (fcurpos2 - tab->bodypos)/tab->bytepix;
+#endif // HAVE_CFITSIO
+
       if (wfield)
+        {
         QFTELL(wfcurpos2, wtab->cat->file, wfield->filename);
+#ifdef HAVE_CFITSIO
+        cfitsio_wfcurpos2 = (wfcurpos2 - wtab->bodypos)/wtab->bytepix;
+#endif // HAVE_CFITSIO
+        }
       if (j == ny-1 && (n=field->height%field->backh))
         {
         meshsize = n*(size_t)w;
@@ -207,13 +229,20 @@ void	make_back(fieldstruct *field, fieldstruct *wfield, int wscale_flag)
 
 /*---- Read and skip, read and skip, etc... */
       QFSEEK(tab->cat->file, bufshift*tab->bytepix, SEEK_CUR, field->filename);
+#ifdef HAVE_CFITSIO
+      tab->currentElement += bufshift;
+#endif // HAVE_CFITSIO
       buft = buf;
       for (i=nlines; i--; buft += w)
         {
         read_body(tab, buft, w);
-        if (i)
+        if ((i)) {
           QFSEEK(tab->cat->file, jumpsize*tab->bytepix, SEEK_CUR,
 		field->filename);
+#ifdef HAVE_CFITSIO
+          tab->currentElement += jumpsize;
+#endif // HAVE_CFITSIO
+        }
         }
 
       if (wfield)
@@ -221,19 +250,30 @@ void	make_back(fieldstruct *field, fieldstruct *wfield, int wscale_flag)
 /*------ Read and skip, read and skip, etc... now on the weight-map */
         QFSEEK(wtab->cat->file,bufshift*wtab->bytepix, SEEK_CUR,
 		wfield->filename);
+#ifdef HAVE_CFITSIO
+        wtab->currentElement += bufshift;
+#endif // HAVE_CFITSIO
         wbuft = wbuf;
         for (i=nlines; i--; wbuft += w)
           {
           read_body(wtab, wbuft, w);
           weight_to_var(wbuft, w);
-          if (i)
+          if ((i))
+            {
             QFSEEK(wtab->cat->file, jumpsize*wtab->bytepix, SEEK_CUR,
 		wfield->filename);
+#ifdef HAVE_CFITSIO
+            wtab->currentElement += jumpsize;
+#endif // HAVE_CFITSIO
+            }
           }
         }
       backstat(backmesh, wbackmesh, buf, wbuf, bufsize, nx, w, bw,
 	wfield?wfield->var_thresh:0.0);
       QFSEEK(tab->cat->file, fcurpos2, SEEK_SET, field->filename);
+#ifdef HAVE_CFITSIO
+      tab->currentElement = (cfitsio_fcurpos2 == 0) ? 1 : cfitsio_fcurpos2;
+#endif // HAVE_CFITSIO
       bm = backmesh;
       for (m=nx; m--; bm++)
         if (bm->mean <= -BIG)
@@ -243,6 +283,9 @@ void	make_back(fieldstruct *field, fieldstruct *wfield, int wscale_flag)
       if (wfield)
         {
         QFSEEK(wtab->cat->file, wfcurpos2, SEEK_SET, wfield->filename);
+#ifdef HAVE_CFITSIO
+        wtab->currentElement = (cfitsio_wfcurpos2 == 0) ? 1 : cfitsio_wfcurpos2;
+#endif // HAVE_CFITSIO
         wbm = wbackmesh;
         for (m=nx; m--; wbm++)
           if (wbm->mean <= -BIG)
@@ -297,8 +340,16 @@ void	make_back(fieldstruct *field, fieldstruct *wfield, int wscale_flag)
 
 /* Go back to the original position */
   QFSEEK(field->tab->cat->file, fcurpos, SEEK_SET, field->filename);
-  if (wfield)
+#ifdef HAVE_CFITSIO
+  field->tab->currentElement = (cfitsio_fcurpos == 0) ? 1 : cfitsio_fcurpos;
+#endif // HAVE_CFITSIO
+
+  if (wfield) {
     QFSEEK(wfield->tab->cat->file, wfcurpos, SEEK_SET, wfield->filename);
+#ifdef HAVE_CFITSIO
+    wfield->tab->currentElement = (cfitsio_wfcurpos == 0) ? 1 : cfitsio_wfcurpos;
+#endif // HAVE_CFITSIO
+  }
 
 /* Median-filter and check suitability of the background map */
   NFPRINTF(OUTPUT, "Filtering background map(s) ...");
