@@ -7,7 +7,7 @@
 *
 *	This file part of:	SWarp
 *
-*	Copyright:		(C) 2000-2013 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 2000-2019 IAP/CNRS/SorbonneU
 *
 *	License:		GNU General Public License
 *
@@ -22,7 +22,7 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SWarp. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		06/06/2013
+*	Last modified:		20/12/2019
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -60,12 +60,14 @@ INPUT	Cat structure,
 	FITS extension number in file (0=primary)
 	Field number in coaddition (for various config settings)
 	Field flags,
+	FITS header filename (null=none).
 OUTPUT	The new field pointer if OK, NULL otherwise.
 NOTES	-.
 AUTHOR	E. Bertin (IAP)
-VERSION	25/08/2010
+VERSION	26/11/2015
  ***/
-fieldstruct	*load_field(catstruct *cat, int frameno, int fieldno)
+fieldstruct	*load_field(catstruct *cat, int frameno, int fieldno,
+			char *hfilename)
 
   {
    tabstruct	*tab, *intab;
@@ -97,22 +99,32 @@ fieldstruct	*load_field(catstruct *cat, int frameno, int fieldno)
   else
     field->rfilename++;
 
+/* Check if a header filename is provided */
+  if (hfilename && *hfilename)
+    strcpy(field->hfilename, hfilename);
+  else { 
 /* Create a file name with a "header" extension */
-  strcpy(field->hfilename, field->filename);
-  if (!(pstr = strrchr(field->hfilename, '.')))
-    pstr = field->hfilename+strlen(field->hfilename);
-  sprintf(pstr, "%s", prefs.head_suffix);
+    strcpy(field->hfilename, field->filename);
+    if (!(pstr = strrchr(field->hfilename, '.')))
+      pstr = field->hfilename+strlen(field->hfilename);
+    sprintf(pstr, "%s", prefs.head_suffix);
+  }
 
   sprintf(gstr, "Looking for %s ...", field->rfilename);
   NFPRINTF(OUTPUT, gstr);
 
 /* Insert additional header informations from the "header" file */
   field->headflag = !read_aschead(field->hfilename, frameno, tab);
-
+  if (hfilename && *hfilename && !field->headflag)
+    warning(hfilename, " header file not found");
   if (tab->naxis<1)
     error(EXIT_FAILURE, "*Error*: Zero-dimensional table in ",field->filename);
 
 /* Force data to be at least 2D */
+#ifdef CFITSTIO_SUPPORT
+// CFITSIO: only valid when NOT tile compressed
+  if(!tab->isTileCompressed)
+#endif // HAVE_CFITSIO
   if (tab->naxis<2)
     {
     tab->naxis = 2;
@@ -351,19 +363,21 @@ void	printinfo_field(fieldstruct *field, fieldstruct *wfield)
 
 /******* init_field ********************************************************
 PROTO	fieldstruct *init_field(fieldstruct **infield, int ninput,
-				char *filename)
+				char *filename, char *hfilename)
 
 PURPOSE	Automatically set appropriate output field parameters according to the
 	prefs and a set of input fields.
 INPUT	Input field ptr array,
 	number of input fields,
-	Filename.
+	Filename,
+	FITS header filename (null=none).
 OUTPUT	Pointer to the new output field.
 NOTES   Global preferences are used.
 AUTHOR  E. Bertin (IAP)
-VERSION 06/06/2013
+VERSION 20/12/2019
  ***/
-fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
+fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename,
+			char *hfilename)
   {
    extern char		celsysname[][2][8];
 
@@ -371,7 +385,7 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
    tabstruct		*tab;
    wcsstruct		*wcs;
    double		pixscale[NAXIS],
-			val, epoch, obsdate;
+			val, epoch, obsdate, obsend;
    float		*scale;
    char			*ctype[NAXIS],
 			*pstr;
@@ -389,11 +403,16 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
     field->rfilename = field->filename;
   else
     field->rfilename++;
-/* Create a file name with a "header" extension */
-  strcpy(field->hfilename, filename);
-  if (!(pstr = strrchr(field->hfilename, '.')))
-    pstr = field->hfilename+strlen(field->hfilename);
-  sprintf(pstr, "%s", prefs.head_suffix);
+/* Check if a header filename is provided */
+  if (hfilename && *hfilename)
+    strcpy(field->hfilename, hfilename);
+  else { 
+/*-- Create a file name with a "header" extension */
+    strcpy(field->hfilename, filename);
+    if (!(pstr = strrchr(field->hfilename, '.')))
+      pstr = field->hfilename+strlen(field->hfilename);
+    sprintf(pstr, "%s", prefs.head_suffix);
+  }
 
   field->cat = new_cat(1);
   init_cat(field->cat);
@@ -506,16 +525,29 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
               {
               wcsmin2 = infield[i]->wcs->wcsmin[axis[i*naxis+n]];
               wcsmax2 = infield[i]->wcs->wcsmax[axis[i*naxis+n]];
-/*------------ Test for the lower limit */
-              if ((n==lng && fcmp_0_p360(wcsmin1, wcsmin2)) || wcsmin1>wcsmin2)
-                countmin++;
-              if ((n==lng && fcmp_0_p360(wcsmax2, wcsmin1)) || wcsmax2>wcsmin1)
-                countmin++;
-/*------------ Test for the upper limit */
-              if ((n==lng && fcmp_0_p360(wcsmax2, wcsmax1)) || wcsmax2>wcsmax1)
-                countmax++;
-              if ((n==lng && fcmp_0_p360(wcsmax1, wcsmin2)) || wcsmax1>wcsmin2)
-                countmax++;
+/*------------ Test for the lower and upper limits */
+              if (lng==lat || n!=lng)
+                {
+                if (wcsmin1>wcsmin2)
+                  countmin++;
+                if (wcsmax2>wcsmin1)
+                  countmin++;
+                if (wcsmax2>wcsmax1)
+                  countmax++;
+                if (wcsmax1>wcsmin2)
+                  countmax++;
+                }
+              else
+                {
+                if (fcmp_0_p360(wcsmin1, wcsmin2))
+                  countmin++;
+                if (fcmp_0_p360(wcsmax2, wcsmin1))
+                  countmin++;
+                if (fcmp_0_p360(wcsmax2, wcsmax1))
+                  countmax++;
+                if (fcmp_0_p360(wcsmax1, wcsmin2))
+                  countmax++;
+                }
               }
 
 /*---------- Update the "most intersecting" limits */
@@ -531,7 +563,7 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
               }
             }
           wcs->crval[n] = (wcsmin[n]+wcsmax[n])/2.0;
-          if (n==lng)
+          if (lat!=lng && n==lng)
             wcs->crval[n] = wcsmax[n]>wcsmin[n]? fmod_0_p360(wcs->crval[n])
 					: fmod_0_p360(wcs->crval[n] - 180.0);
           break;
@@ -543,12 +575,21 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
             {
             wcsmin2 = infield[i]->wcs->wcsmin[axis[i*naxis+n]];
             wcsmax2 = infield[i]->wcs->wcsmax[axis[i*naxis+n]];
-/*---------- Test for the lower limit */
-            if ((n==lng && fcmp_0_p360(wcsmin[n],wcsmin2)) || wcsmin[n]>wcsmin2)
-              wcsmin[n] = wcsmin2;
-/*---------- Test for the upper limit */
-            if ((n==lng && fcmp_0_p360(wcsmax2,wcsmax[n])) || wcsmax2>wcsmax[n])
-              wcsmax[n] = wcsmax2;
+/*---------- Test for the lower and upper limits */
+            if (lng==lat || n!=lng)
+              {
+              if (wcsmin[n]>wcsmin2)
+                wcsmin[n] = wcsmin2;
+              if (wcsmax2>wcsmax[n])
+                wcsmax[n] = wcsmax2;
+              }
+            else
+              {
+              if (fcmp_0_p360(wcsmin[n],wcsmin2))
+                wcsmin[n] = wcsmin2;
+              if (fcmp_0_p360(wcsmax2,wcsmax[n]))
+                wcsmax[n] = wcsmax2;
+              }
             }
           wcs->crval[n] = (wcsmin[n]+wcsmax[n])/2.0;
           if (n==lng)
@@ -563,12 +604,21 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
             {
             wcsmin2 = infield[i]->wcs->wcsmin[axis[i*naxis+n]];
             wcsmax2 = infield[i]->wcs->wcsmax[axis[i*naxis+n]];
-/*---------- Test for the lower limit */
-            if ((n==lng && fcmp_0_p360(wcsmin[n],wcsmin2)) || wcsmin[n]>wcsmin2)
-              wcsmin[n] = wcsmin2;
-/*---------- Test for the upper limit */
-            if ((n==lng && fcmp_0_p360(wcsmax2,wcsmax[n])) || wcsmax2>wcsmax[n])
-              wcsmax[n] = wcsmax2;
+/*---------- Test for the lower and upper limits */
+            if (lng==lat || n!=lng)
+              {
+              if (wcsmin[n]>wcsmin2)
+                wcsmin[n] = wcsmin2;
+              if (wcsmax2>wcsmax[n])
+                wcsmax[n] = wcsmax2;
+              }
+            else
+              {
+              if (fcmp_0_p360(wcsmin[n],wcsmin2))
+                wcsmin[n] = wcsmin2;
+              if (fcmp_0_p360(wcsmax2,wcsmax[n]))
+                wcsmax[n] = wcsmax2;
+              }
             }
 /*-------- Handled swapped ra, dec axes (e.g. SDSS) */
           npstr = n;
@@ -581,7 +631,7 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
             }
           pstr = prefs.image_center[npstr];
   	  wcs->crval[n] = strchr(pstr, ':') ?
-			  (n==lng?sextodegal(pstr):sextodegde(pstr))
+			((lat!=lng && n==lng)?sextodegal(pstr):sextodegde(pstr))
 			: atof(pstr);
          break;
 
@@ -884,23 +934,30 @@ fieldstruct *init_field(fieldstruct **infield, int ninput, char *filename)
 
   free(axis);
 
-/* Compute mean epoch */
+/* Compute mean epoch and observation start/end */
   epoch = 0.0;
   obsdate = BIG;
+  obsend = -BIG;
   for (j=0; j<ninput; j++)
     {
     epoch += infield[j]->wcs->epoch;
-    if (infield[j]->wcs->obsdate<obsdate)
+    if (infield[j]->wcs->obsdate != 0.0 && infield[j]->wcs->obsdate < obsdate)
       obsdate = infield[j]->wcs->obsdate;
+    if (infield[j]->wcs->obsend > obsend)
+      obsend = infield[j]->wcs->obsend;
     }
   field->wcs->epoch = epoch / ninput;
-  field->wcs->obsdate = obsdate;
+  field->wcs->obsdate = (obsdate < BIG ? obsdate : 0.0);
+  field->wcs->obsend = obsend;
+
   update_head(tab);
   write_wcs(tab, wcs);
 /* Insert additional header informations from the "header" file */
   if (read_aschead(field->hfilename, 0, tab))
     {
 /*-- No external header: update WCS internal structures only */
+    if (hfilename && *hfilename)
+      warning(hfilename, " header file not found");
     if (!wcs->wcsprm)
       QCALLOC(wcs->wcsprm, struct wcsprm, 1);
 /*-- Test if the WCS is recognized and a celestial pair is found */
