@@ -7,7 +7,7 @@
 *
 *	This file part of:	AstrOmatic FITS/LDAC library
 *
-*	Copyright:		(C) 1995-2019 IAP/CNRS/SorbonneU
+*	Copyright:		(C) 1995-2020 IAP/CNRS/SorbonneU
 *
 *	License:		GNU General Public License
 *
@@ -23,7 +23,7 @@
 *	along with AstrOmatic software.
 *	If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		03/12/2019
+*	Last modified:		26/08/2020
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -87,22 +87,23 @@ INPUT	pointer to the catalog structure,
 	pointer to the table structure.
 OUTPUT	-.
 NOTES	-.
-AUTHOR	E. Bertin (IAP & Leiden observatory)
-VERSION	13/06/2012
+AUTHOR	E. Bertin (IAP)
+VERSION	11/02/2020
  ***/
 void	save_tab(catstruct *cat, tabstruct *tab)
 
   {
-   catstruct	*tabcat;
-   keystruct	*key;
-   tabstruct	*keytab;
-   KINGSIZE_T	tabsize;
-   long		size;
-   int		b,j,k,o, nbytes,nkey,nobj,spoonful,
-		tabflag, larrayin,larrayout;
-   char		*buf, *inbuf, *outbuf, *fptr,*ptr;
-   int		esize;
+   catstruct		*tabcat;
+   keystruct		*key;
+   tabstruct		*keytab;
+   KINGSIZE_T		tabsize;
+   long			size;
+   char			*buf, *inbuf, *outbuf, *fptr,*ptr;
+   unsigned short	ashort = 1;
+   int			b,j,k,o, nbytes,nkey,nobj,spoonful,
+			tabflag, larrayin,larrayout, esize, bswapflag;
 
+  bswapflag = *((char *)&ashort);	// Byte-swapping flag
 /*  The header itself*/
   tabflag = save_head(cat, tab)==RETURN_OK?1:0;
 /*  Allocate memory for the output buffer */
@@ -314,18 +315,21 @@ INPUT	Table structure,
 	pointer to the temporary buffer.
 OUTPUT	-.
 NOTES	key content is destroyed (actually, byte-swapped) on output.
-AUTHOR	E. Bertin (IAP & Leiden observatory)
-VERSION	27/08/2012
+AUTHOR	E. Bertin (IAP)
+VERSION	11/02/2020
  ***/
 int	write_obj(tabstruct *tab, char *buf)
 
   {
-   keystruct    *key;
-   char         *pin, *pout, *pout2;
-   int          b,k;
-   int          esize;
+   catstruct		*cat;
+   keystruct		*key;
+   char  	       *pin, *pout, *pout2;
+   unsigned short	ashort = 1;
+   int          	b, k, esize, bswapflag;
 
+  bswapflag = *((char *)&ashort);	// Byte-swapping flag
   key = tab->key;
+  cat = tab->cat;
   pout = buf;
   for (k=tab->nkey; k--; key = key->nextkey)
     {
@@ -340,7 +344,7 @@ int	write_obj(tabstruct *tab, char *buf)
       }
     }
 
-  QFWRITE(buf, *tab->naxisn, tab->cat->file, tab->cat->filename);
+  QFWRITE(buf, *tab->naxisn, cat->file, cat->filename);
 
   return ++tab->naxisn[1];
   }
